import re
import datetime
from youtubed2x_lib.parsers import Parser_Helper, getPage


class MySpaceTV_Parser (Parser_Helper):
    """Parser for MySpaceTV pages. Updated 01/15/2010"""
    const_video_url_re = re.compile (r'^(?:http://)?vids\.myspace\.com/index\.cfm\?fuseaction=vids\.individual&(?:v|V)ideo(?:id|ID)=(\d+)')
    video_url_str = 'http://vids.myspace.com/index.cfm?fuseaction=vids.individual&videoid=%s'
    video_details_str = "http://mediaservices.myspace.com/services/rss.ashx?videoID=%s&type=video"
    video_title_re = re.compile (r"<item>\r\n      <title>([^<]*)</title>")
    video_url_params_re = re.compile (r'<media:content url="(\S+)" type="video/x-flv"')
    parser_type = "MySpaceTV"
    domain_str = "http://vids.myspace.com/"
    host_str = "vids.myspace.com"
    version = datetime.date (2010, 1, 15)


    def getVideoPage (self, account="", password=""):
        page, newurl = getPage (self.video_details_str % self.video_id)
        self.page_dump = page
        return page, newurl


    def _parseRealURL (self, commands):
        """Get the real url for the video"""
        real_url = commands[0]
        return real_url


    @staticmethod
    def getImageData ():
        image_data = """\x00\x00\x00\x00\x00\x00\x00\x00D\x9e\xe9!D\x9e\xe9\x96\x00\x00\x00\x00D\x9e\xe9\xfbD\x9e\xe9\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00D\x9e\xe9ND\x9e\xe9E\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00D\x9e\xe9\xeaD\x9e\xe9\xf3D\x9e\xe9\xdeD\x9e\xe9\xff\x00\x00\x00\x00\x00\x00\x00\x00D\x9e\xe9\x12D\x9e\xe9\xffD\x9e\xe99\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00D\x9e\xe9\xcfD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xff\x00\x00\x00\x00D\x9e\xe9\xffD\x9e\xe9\xc6\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00D\x9e\xe9\xff\xb4\xc4\xd1\xff\xcc\xcc\xcc\xff\xcc\xcc\xcc\xff\xcc\xcc\xcc\xff\xd7\xd7\xd7\xff\xcc\xcc\xcc\xffD\x9e\xe9\xffD\x9e\xe9\xd2D\x9e\xe9\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00D\x9e\xe9\xff\xc0\xc0\xc0\xff\xef\xef\xef\xff\xff\xff\xff\xff\xec\xec\xec\xff\xff\xff\xff\xff\xc9\xc9\xc9\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xbdD\x9e\xe9\xff\xa1\xa1\xa1\xff\xce\xce\xce\xff\xbc\xbc\xbc\xff\xa1\xa1\xa1\xff\xc6\xc6\xc6\xff\xa0\xa0\xa0\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xff9\x89\xcd\xff\xaf\xc1\xd0\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xf9\xf9\xf9\xff9\x89\xcd\xff\xcc\xcc\xcc\xff\xcc\xcc\xcc\xff\xcc\xcc\xcc\xff\xcc\xcc\xcc\xff\xcc\xcc\xcc\xff\x86\xb4\xdb\xffD\x9e\xe9\xffD\x9e\xe9\xff:\x8b\xd0\xff9\x89\xcd\xff9\x89\xcd\xff9\x89\xcd\xff9\x89\xcd\xff9\x89\xcd\xff9\x89\xcd\xff9\x89\xcd\xff\xcc\xcc\xcc\xff\xcc\xcc\xcc\xff\xe2\xe2\xe2\xff\xff\xff\xff\xff\xfd\xfd\xfd\xff\xcc\xcc\xcc\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xff\xc4\xc9\xce\xff\xcc\xcc\xcc\xff\xcc\xcc\xcc\xff\xcc\xcc\xcc\xff\xe5\xe5\xe5\xff\xff\xff\xff\xff\xfa\xfa\xfa\xff\xcc\xcc\xcc\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe0\xe0\xe0\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xffD\x9e\xe9\xff\xc4\xc9\xce\xff\xff\xff\xff\xff\xff\xff\xff\xff\xcc\xcc\xcc\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xcc\xcc\xcc\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd3\xd3\xd3\xffD\x9e\xe9\xffD\x9e\xe9\xff=\x91\xd8\xff;\x8d\xd3\xff\xc3\xc8\xcc\xff\xe1\xe1\xe1\xff\xf7\xf7\xf7\xff\xa0\xa0\xa0\xff\xaa\xaa\xaa\xff\xff\xff\xff\xff\xc4\xc4\xc4\xff\xa0\xa0\xa0\xff\xa0\xa0\xa0\xff\xd0\xd0\xd0\xff\xb3\xb3\xb3\xff\xcb\xcb\xcb\xff;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\xff\x9e\xa3\xa7\xff\xfc\xfc\xfc\xff\xff\xff\xff\xff\xad\xad\xad\xff\xca\xca\xca\xff\xff\xff\xff\xff\xef\xef\xef\xff\xa0\xa0\xa0\xff\xe8\xe8\xe8\xff\xff\xff\xff\xff\xff\xff\xff\xff\xbc\xbc\xbc\xff;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\xff\xa5\xad\xb3\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf5\xf5\xf5\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\xffW\x94\xc9\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf7\xf7\xf7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfa\xfc\xfe\xff;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\xd2;\x8d\xd3\xff;\x8d\xd3\xff\x93\xc0\xe7\xff\xff\xff\xff\xff\xf7\xf7\xf7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xcc\xe1\xf4\xff;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\x03;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\xff;\x8d\xd3\xab"""

        return image_data


