import re
import datetime
from youtubed2x_lib.parsers import Parser_Helper


class MyVideo_Parser (Parser_Helper):
    """Parser for MyVideo pages. Updated 07/04/2009"""
    const_video_url_re = re.compile (r'^(?:http://)?(?:www\.)?myvideo\.de/watch/(\d+)(?:/\S+)?$')
    video_url_str = 'http://www.myvideo.de/watch/%s/'
    video_title_re = re.compile (r"<td class='globalHd'>([^<]*)</td>")
    video_url_params_re = re.compile (r"<link rel='image_src' href='(\S+)' />")
    parser_type = "MyVideo"
    domain_str = "http://www.myvideo.de/"
    host_str = "myvideo.de"
    version = datetime.date (2009, 11, 28)


    def _parseRealURL (self, commands):
        """Get the real url for the video"""
        partial_url = commands[0].split ("thumbs")[0]
        real_url = "%s%s.flv" % (partial_url, self.video_id)
        return real_url


    @staticmethod
    def getImageData ():
        image_data = """\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf3\xf8\xfd\xff\x92\xbc\xf0\xffI\x8f\xe7\xff=\x88\xe5\xffI\x8f\xe7\xff\x9e\xc3\xf2\xff\xf3\xf8\xfd\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf3\xf8\xfd\xffb\x9e\xea\xff=\x88\xe5\xffU\x97\xe8\xff\x92\xbc\xf0\xff\x9e\xc4\xf2\xffa\x9e\xea\xffb\x9e\xea\xff\xf3\xf8\xfd\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xffz\xad\xed\xff=\x88\xe5\xffz\xad\xed\xff\xf3\xf8\xfd\xff\xe7\xf0\xfc\xff\xf3\xf8\xfd\xff\xff\xff\xff\xff\xb6\xd2\xf5\xffz\xad\xed\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xda\xe9\xfa\xff=\x88\xe5\xffU\x97\xe8\xff\xf3\xf8\xfd\xff\xdb\xe9\xfa\xff\x92\xbc\xf0\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x92\xbc\xf0\xff\xce\xe1\xf8\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x92\xbc\xf0\xff=\x88\xe5\xff\xaa\xcb\xf4\xff\xff\xff\xff\xffz\xad\xed\xff\xf3\xf8\xfd\xff\xff\xff\xff\xff\xff\xcf\xaf\xff\xff\xff\xff\xff\xf3\xf8\xfd\xff\x86\xb5\xef\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xffn\xa6\xec\xff=\x88\xe5\xff\xe7\xf0\xfc\xff\xff\xff\xff\xffn\xa6\xec\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x8c@\xff\xffy \xff\xff\xd9\xbf\xff\x9e\xc4\xf2\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xffI\x8f\xe7\xff=\x88\xe5\xff\xff\xff\xff\xff\xff\xff\xff\xffU\x97\xe8\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x8c@\xff\xfff\x00\xff\xfff\x00\xff\xff\x96P\xff\xff\xec\xe0\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff=\x88\xe5\xff=\x88\xe5\xff\xff\xff\xff\xff\xff\xff\xff\xffI\x8f\xe7\xff\x92\xbc\xf0\xff\xff\xff\xff\xff\xff\x8c@\xff\xfff\x00\xff\xfff\x00\xff\xfff\x00\xff\xffp\x10\xff\xff\xbc\x8f\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff=\x88\xe5\xff=\x88\xe5\xff\xff\xff\xff\xff\xff\xff\xff\xff\x92\xbc\xf0\xff=\x88\xe5\xff\xff\xff\xff\xff\xff\x8c@\xff\xfff\x00\xff\xfff\x00\xff\xfff\x00\xff\xfff\x00\xff\xfff\x00\xff\xff\x9f`\xff\xff\xff\xff\xff\xff\xff\xff\xffn\xa6\xec\xff=\x88\xe5\xff\xe7\xf0\xfc\xff\xff\xff\xff\xff\xf3\xf8\xfd\xffa\x9e\xea\xff\xff\xff\xff\xff\xff\x8c@\xff\xfff\x00\xff\xfff\x00\xff\xfff\x00\xff\xffy \xff\xff\xc6\x9f\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x86\xb5\xef\xff=\x88\xe5\xff\xb6\xd2\xf5\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x8c@\xff\xfff\x00\xff\xffp\x10\xff\xff\xb3\x80\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb6\xd2\xf5\xff=\x88\xe5\xffn\xa6\xec\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x8c@\xff\xff\xb3\x80\xff\xff\xf5\xef\xff\x85\xb5\xee\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf3\xf8\xfd\xffI\x8f\xe7\xff=\x88\xe5\xff\xc2\xda\xf7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xaa\xcb\xf4\xff\x9e\xc3\xf2\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xaa\xcb\xf4\xff=\x88\xe5\xffI\x8f\xe7\xff\xc2\xda\xf7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb6\xd2\xf5\xffI\x8f\xe7\xff\xf3\xf8\xfd\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x86\xb5\xef\xff=\x88\xe5\xff=\x88\xe5\xffa\x9e\xea\xffn\xa6\xec\xffa\x9e\xea\xff=\x88\xe5\xff\xc2\xda\xf7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x9e\xc3\xf2\xffI\x8f\xe7\xff=\x88\xe5\xff=\x88\xe5\xffb\x9e\xea\xff\xce\xe1\xf8\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""

        return image_data


