import re
import datetime
import urllib2
from youtubed2x_lib.parsers import Parser_Helper, getPage


class Spike_Parser (Parser_Helper):
    """Parser for SpikeTv pages. Updated 01/15/2010"""
    const_video_url_re = re.compile (r'^(?:http://)?(?:www\.)?spike\.com/video/((\S+)/(\d+))')
    video_url_str = 'http://www.spike.com/video/%s'
    video_details_xml_url = "http://www.spike.com/ui/xml/mediaplayer/mediagen.groovy?videoId=%s"
    video_title_re = re.compile (r'<meta name="title" content="([\S ]+)"(?:\s+)?/>')
    video_url_params_re = re.compile (r'<src>(\S+)</src>')
    parser_type = "Spike"
    domain_str = "http://www.spike.com/"
    host_str = "spike.com"
    version = datetime.date (2010, 1, 15)


    def _parsePlayerCommands (self):
        """Get the commands needed to get the video player"""
        page, newurl = getPage (self.__class__.video_details_xml_url % self.video_id.rsplit ("/", 1)[1])
        match = self.video_url_params_re.search (page)
        if not match:
            raise self.__class__.InvalidCommands ("Could not find flash player commands")
        else:
            commands = match.groups ()
        return commands


    def _parseRealURL (self, commands):
        """Get the real url for the video"""
        real_url = urllib2.unquote (commands[0]).replace ("&amp;", "&")
        return real_url


    @staticmethod
    def getImageData ():
        image_data = """\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\x00\x00\x00\xff\xff\xff\xff\xff\xff\xff\xff\xff\x00\x00\x00\xff\x00\x00\x00\xff\xff\xff\xff\xff\xff\xff\xff\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\x00\x00\x00\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf5\xb8\x03\xff\xf5\xb8\x03\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""

        return image_data


